[llvm-commits] CVS: llvm/include/llvm/CodeGen/DwarfWriter.h

Jim Laskey jlaskey at apple.com
Mon Jan 29 10:51:37 PST 2007



Changes in directory llvm/include/llvm/CodeGen:

DwarfWriter.h updated: 1.44 -> 1.45
---
Log message:

Landing pad-less eh for PPC.

---
Diffs of the changes:  (+12 -7)

 DwarfWriter.h |   19 ++++++++++++-------
 1 files changed, 12 insertions(+), 7 deletions(-)


Index: llvm/include/llvm/CodeGen/DwarfWriter.h
diff -u llvm/include/llvm/CodeGen/DwarfWriter.h:1.44 llvm/include/llvm/CodeGen/DwarfWriter.h:1.45
--- llvm/include/llvm/CodeGen/DwarfWriter.h:1.44	Fri Jan 26 15:22:27 2007
+++ llvm/include/llvm/CodeGen/DwarfWriter.h	Mon Jan 29 12:51:14 2007
@@ -7,11 +7,11 @@
 //
 //===----------------------------------------------------------------------===//
 //
 // This file contains support for writing Dwarf debug info into asm files.  For
 // Details on the Dwarf 3 specfication see DWARF Debugging Information Format
 // V.3 reference manual http://dwarf.freestandards.org ,
 //
-// The role of the Dwarf Writer class is to extract debug information from the
+// The role of the Dwarf Writer class is to extract information from the
 // MachineModuleInfo object, organize it in Dwarf form and then emit it into asm
 // the current asm file using data and high level Dwarf directives.
 // 
@@ -25,7 +25,8 @@
 namespace llvm {
 
 class AsmPrinter;
-class Dwarf;
+class DwarfDebug;
+class DwarfException;
 class MachineModuleInfo;
 class MachineFunction;
 class Module;
@@ -37,9 +38,13 @@
 
 class DwarfWriter {
 private:
   /// DM - Provides the DwarfWriter implementation.
   ///
-  Dwarf *DW;
+  DwarfDebug *DD;
+
+  /// DE - Provides the DwarfWriter exception implementation.
+  ///
+  DwarfException *DE;
   
 public:
   
@@ -7,11 +7,11 @@
 //===----------------------------------------------------------------------===//
 //
-// This file contains support for writing Dwarf debug info into asm files.  For
-// Details on the Dwarf 3 specfication see DWARF Debugging Information Format
-// V.3 reference manual http://dwarf.freestandards.org ,
+// This file contains support for writing Dwarf debug and exception info into
+// asm files.  For Details on the Dwarf 3 specfication see DWARF Debugging
+// Information Format V.3 reference manual http://dwarf.freestandards.org ,
 //
@@ -37,9 +38,13 @@
 class DwarfWriter {
 private:
-  /// DM - Provides the DwarfWriter implementation.
+  /// DD - Provides the DwarfWriter debug implementation.
   ///






More information about the llvm-commits mailing list